package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcBrandProjectProgressMapper;
import com.ruoyi.oa.domain.CmcBrandProjectProgress;
import com.ruoyi.oa.service.ICmcBrandProjectProgressService;

/**
 * cmc品牌项目进度Service业务层处理
 * 
 * @author cmc
 * @date 2024-06-12
 */
@Service
public class CmcBrandProjectProgressServiceImpl implements ICmcBrandProjectProgressService 
{
    @Autowired
    private CmcBrandProjectProgressMapper cmcBrandProjectProgressMapper;

    /**
     * 查询cmc品牌项目进度
     * 
     * @param progressId cmc品牌项目进度主键
     * @return cmc品牌项目进度
     */
    @Override
    public CmcBrandProjectProgress selectCmcBrandProjectProgressByProgressId(Long progressId)
    {
        return cmcBrandProjectProgressMapper.selectCmcBrandProjectProgressByProgressId(progressId);
    }

    /**
     * 查询cmc品牌项目进度列表
     * 
     * @param cmcBrandProjectProgress cmc品牌项目进度
     * @return cmc品牌项目进度
     */
    @Override
    public List<CmcBrandProjectProgress> selectCmcBrandProjectProgressList(CmcBrandProjectProgress cmcBrandProjectProgress)
    {
        return cmcBrandProjectProgressMapper.selectCmcBrandProjectProgressList(cmcBrandProjectProgress);
    }

    /**
     * 新增cmc品牌项目进度
     * 
     * @param cmcBrandProjectProgress cmc品牌项目进度
     * @return 结果
     */
    @Override
    public int insertCmcBrandProjectProgress(CmcBrandProjectProgress cmcBrandProjectProgress)
    {
        return cmcBrandProjectProgressMapper.insertCmcBrandProjectProgress(cmcBrandProjectProgress);
    }

    /**
     * 修改cmc品牌项目进度
     * 
     * @param cmcBrandProjectProgress cmc品牌项目进度
     * @return 结果
     */
    @Override
    public int updateCmcBrandProjectProgress(CmcBrandProjectProgress cmcBrandProjectProgress)
    {
        return cmcBrandProjectProgressMapper.updateCmcBrandProjectProgress(cmcBrandProjectProgress);
    }

    /**
     * 批量删除cmc品牌项目进度
     * 
     * @param projectIds 需要删除的cmc品牌项目进度主键
     * @return 结果
     */
    @Override
    public int deleteCmcBrandProjectProgressByProgressIds(String[] projectIds)
    {
        return cmcBrandProjectProgressMapper.deleteCmcBrandProjectProgressByProgressIds(projectIds);
    }

    /**
     * 删除cmc品牌项目进度信息
     * 
     * @param progressId cmc品牌项目进度主键
     * @return 结果
     */
    @Override
    public int deleteCmcBrandProjectProgressByProgressId(Long progressId)
    {
        return cmcBrandProjectProgressMapper.deleteCmcBrandProjectProgressByProgressId(progressId);
    }
}
